@@ -62,7 +62,7 @@ class SyncKohaRowsCommand(BaseCommand):
     """ lower case and remove noise characters """
     @staticmethod
     def sanitize(value):
-        chars_to_remove = [';', ':', '/', '.', ',', '(', ')']
+        chars_to_remove = [';', ':', '/', '.', ',', '(', ')', '-', '_']
         if isinstance(value, str):
             value = value.lower()
             value = value.translate({ord(char): '' for char in chars_to_remove})
