@@ -1,3 +1,5 @@
+import pprint
+
 from loguru import logger
 
 from src.commands.BaseCommand import BaseCommand
@@ -10,7 +12,7 @@ import sys
 class ValidateApiCommand(BaseCommand):
 
     def __init__(self):
-        self.status = 'status'
+        self.add_koha = 'api/koha'
         self.headers = {
             "Accept": "application/json"
         }
@@ -20,21 +22,13 @@ class ValidateApiCommand(BaseCommand):
         logger.info("VALIDATING API AVAILABILITY")
 
         try:
-            status_req = requests.get(f"{Config.config['target']['url_status']}/{self.status}", headers=self.headers)
+            status_req = requests.post(f"{Config.config['target']['url_add']}/{self.add_koha}", headers=self.headers)
         except Exception as e:
             sys.exit(logger.error(f"There was an error for request  : {e.args}"))
 
-        if status_req.status_code is not 200:
-            sys.exit(logger.error(f"API {Config.config['target']['url_status']}/{self.status} "
+        if status_req.status_code != 401:
+            sys.exit(logger.error(f"API {Config.config['target']['url_add']}/{self.add_koha} "
                                   f"status code {status_req.status_code}"))
 
         else:
-            logger.success(f"API status code : 200")
-
-            if status_req.json()['status'] != "ok":
-                sys.exit(logger.error(f"API not available"))
-            else:
-                logger.success(f"API availability : OK")
-
-        # TODO
-        # validate /api/koha API availability
+            logger.success(f"API available")
