@@ -1,26 +1,27 @@
-from loguru import logger
+import sys
+import click
 
+from loguru import logger
 from src.commands.SyncKohaRowsCommand import SyncKohaRowsCommand
 from src.commands.LoadConfigFileCommand import LoadConfigFileCommand
 from src.commands.ValidateApiCommand import ValidateApiCommand
 from src.commands.ValidateKohaDBCommand import ValidateKohaDBCommand
 
-import click
+
+koha_sync_version = '1.1.2'
 
 
 @click.command()
 @click.option('-c', '--config-file', 'config_file', required=True, help="path to configuration file")
 @click.option('-v', '--verbose', 'verbosity', count=True, help="activate verbosity output")
+@click.option('-V', '--version', 'version', is_flag=True, help="print current cli version and stops execution")
 @click.option('-r', '--run-once', 'run_once', is_flag=True, help="synchronize once and stops execution")
 @click.option('-t', '--test', 'test', is_flag=True, help="run validations and stops before synchronize")
-def main(config_file, verbosity, run_once, test):
+def main(config_file, verbosity, run_once, test, version):
     # click.secho('Hello {0} {1} {3} {2}'.format(config_file, verbosity, test, run_once))
     # click.secho(f'Hello {config_file} {verbosity} {run_once} {test}')
-
-    # TODO
-    # verify requirements before execution
-    # ValidateRequirementsCommand().execute()
-    # print out the current version
+    if version:
+        sys.exit(logger.success(f"you are running {koha_sync_version} version"))
 
     # verify and load configuration file
     LoadConfigFileCommand(file_path=config_file).execute()
